==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QDeferredDisposeEvent_shell.cpp <==
#include "QDeferredDisposeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QDeferredDeleteEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDeferredDeleteEvent")
    QDeferredDeleteEvent *_ptr = reinterpret_cast<QDeferredDeleteEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDeferredDisposeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDeferredDisposeEvent_shell) ); }

jmethodID QDeferredDisposeEvent_shell::__shell_javaMethod(int pos) const { return QDeferredDisposeEvent_shell::__shell()->javaMethod(typeid(QDeferredDeleteEvent), pos); }

// emitting (writeShellConstructor)
QDeferredDisposeEvent_shell::QDeferredDisposeEvent_shell()
    : QDeferredDeleteEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDeferredDeleteEvent::QDeferredDisposeEvent_shell()", QDeferredDisposeEvent_shell::__shell())
    QDeferredDisposeEvent_shell::__shell()->constructed(typeid(QDeferredDeleteEvent));
}

QDeferredDisposeEvent_shell::QDeferredDisposeEvent_shell(const QDeferredDeleteEvent& arg__1)
    : QDeferredDeleteEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDeferredDeleteEvent::QDeferredDisposeEvent_shell(const QDeferredDeleteEvent& arg__1)", QDeferredDisposeEvent_shell::__shell())
    QDeferredDisposeEvent_shell::__shell()->constructed(typeid(QDeferredDeleteEvent));
}

// emitting (writeShellDestructor)
QDeferredDisposeEvent_shell::~QDeferredDisposeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDeferredDeleteEvent::~QDeferredDeleteEvent()", QDeferredDisposeEvent_shell::__shell())
    QDeferredDisposeEvent_shell::__shell()->destructed(typeid(QDeferredDeleteEvent));
}

void QDeferredDisposeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDeferredDisposeEvent_shell*>(ptr)->QDeferredDisposeEvent_shell::__shell()->tryDeleteShell(typeid(QDeferredDeleteEvent));
}

// emitting Virtual overrides (virtualFunctions)
QDeferredDeleteEvent* QDeferredDisposeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDeferredDeleteEvent::clone()const", QDeferredDisposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QDeferredDeleteEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QDeferredDisposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QDeferredDeleteEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QDeferredDisposeEvent_shell::__shell()->warnForMethod("QDeferredDeleteEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDeferredDeleteEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QDeferredDeleteEvent::clone();
        }
    }else{
        return QDeferredDeleteEvent::clone();
    }
}

void QDeferredDisposeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QDeferredDeleteEvent::", QDeferredDisposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QDeferredDisposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QDeferredDisposeEvent_shell::__shell()->warnForMethod("QDeferredDeleteEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDeferredDeleteEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QDeferredDisposeEvent_access::__qt_assign_cref_QDeferredDeleteEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QDeferredDeleteEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDeferredDeleteEvent>(__jni_env, other0);
    QDeferredDeleteEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDeferredDisposeEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QDeferredDeleteEvent* __qt_return_value = QDeferredDeleteEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QDeferredDeleteEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QDeferredDeleteEvent()
void __qt_construct_QDeferredDeleteEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDeferredDeleteEvent()")
    Q_UNUSED(__java_arguments)
    QDeferredDeleteEvent *__qt_this = new(__qtjambi_ptr) QDeferredDisposeEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDeferredDeleteEvent(QDeferredDeleteEvent)
void __qt_construct_QDeferredDeleteEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDeferredDeleteEvent(QDeferredDeleteEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QDeferredDeleteEvent& __qt_arg__1 = qtjambi_cast<const QDeferredDeleteEvent& >(__jni_env, arg__1);
    QDeferredDeleteEvent *__qt_this = new(__qtjambi_ptr) QDeferredDisposeEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDeferredDisposeEvent_shell
void __qt_destruct_QDeferredDeleteEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDeferredDeleteEvent")
    reinterpret_cast<QDeferredDisposeEvent_shell*>(ptr)->~QDeferredDisposeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDeferredDeleteEvent::QDeferredDeleteEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_initialize_1native__Lio_qt_core_QDeferredDisposeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDeferredDeleteEvent::QDeferredDeleteEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDeferredDeleteEvent_0, sizeof(QDeferredDisposeEvent_shell), typeid(QDeferredDeleteEvent), true, &deleter_QDeferredDeleteEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDeferredDeleteEvent::QDeferredDeleteEvent(QDeferredDeleteEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_initialize_1native__Lio_qt_core_QDeferredDisposeEvent_2Lio_qt_core_QDeferredDisposeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDeferredDeleteEvent::QDeferredDeleteEvent(QDeferredDeleteEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDeferredDeleteEvent_1, sizeof(QDeferredDisposeEvent_shell), typeid(QDeferredDeleteEvent), true, &deleter_QDeferredDeleteEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDeferredDeleteEvent::loopLevel()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_loopLevel_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDeferredDeleteEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDeferredDeleteEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDeferredDeleteEvent::loopLevel()const", __qt_this)
        __java_return_value = __qt_this->loopLevel();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDeferredDeleteEvent::operator=(QDeferredDeleteEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_assign_1native_1cref_1QDeferredDeleteEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDeferredDeleteEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDeferredDeleteEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDeferredDeleteEvent::operator=(QDeferredDeleteEvent)", __qt_this)
        static_cast<QDeferredDisposeEvent_access*>(__qt_this)->__qt_assign_cref_QDeferredDeleteEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDeferredDeleteEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDeferredDeleteEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDeferredDeleteEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDeferredDeleteEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QDeferredDisposeEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDeferredDeleteEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDeferredDeleteEvent>("QDeferredDeleteEvent", "io/qt/core/QDeferredDisposeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QDeferredDisposeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QDeferredDeleteEvent, {
        ConstructorInfo(&__qt_construct_QDeferredDeleteEvent_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDeferredDeleteEvent_1, "Lio/qt/core/QDeferredDisposeEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDeferredDeleteEvent);
    registerSizeOfShell(typeId, sizeof(QDeferredDisposeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QDeferredDeleteEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QDeferredDisposeEvent_shell.cpp <==
#include "QDeferredDisposeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QDeferredDeleteEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDeferredDeleteEvent")
    QDeferredDeleteEvent *_ptr = reinterpret_cast<QDeferredDeleteEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QDeferredDisposeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QDeferredDisposeEvent_shell) ); }

jmethodID QDeferredDisposeEvent_shell::__shell_javaMethod(int pos) const { return QDeferredDisposeEvent_shell::__shell()->javaMethod(typeid(QDeferredDeleteEvent), pos); }

// emitting (writeShellConstructor)
QDeferredDisposeEvent_shell::QDeferredDisposeEvent_shell()
    : QDeferredDeleteEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDeferredDeleteEvent::QDeferredDisposeEvent_shell()", QDeferredDisposeEvent_shell::__shell())
    QDeferredDisposeEvent_shell::__shell()->constructed(typeid(QDeferredDeleteEvent));
}

QDeferredDisposeEvent_shell::QDeferredDisposeEvent_shell(const QDeferredDeleteEvent& arg__1)
    : QDeferredDeleteEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QDeferredDeleteEvent::QDeferredDisposeEvent_shell(const QDeferredDeleteEvent& arg__1)", QDeferredDisposeEvent_shell::__shell())
    QDeferredDisposeEvent_shell::__shell()->constructed(typeid(QDeferredDeleteEvent));
}

// emitting (writeShellDestructor)
QDeferredDisposeEvent_shell::~QDeferredDisposeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QDeferredDeleteEvent::~QDeferredDeleteEvent()", QDeferredDisposeEvent_shell::__shell())
    QDeferredDisposeEvent_shell::__shell()->destructed(typeid(QDeferredDeleteEvent));
}

void QDeferredDisposeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QDeferredDisposeEvent_shell*>(ptr)->QDeferredDisposeEvent_shell::__shell()->tryDeleteShell(typeid(QDeferredDeleteEvent));
}

// emitting Virtual overrides (virtualFunctions)
QDeferredDeleteEvent* QDeferredDisposeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QDeferredDeleteEvent::clone()const", QDeferredDisposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QDeferredDeleteEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QDeferredDisposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QDeferredDeleteEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QDeferredDisposeEvent_shell::__shell()->warnForMethod("QDeferredDeleteEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDeferredDeleteEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QDeferredDeleteEvent::clone();
        }
    }else{
        return QDeferredDeleteEvent::clone();
    }
}

void QDeferredDisposeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QDeferredDeleteEvent::", QDeferredDisposeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QDeferredDisposeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QDeferredDisposeEvent_shell::__shell()->warnForMethod("QDeferredDeleteEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QDeferredDeleteEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QDeferredDisposeEvent_access::__qt_assign_cref_QDeferredDeleteEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QDeferredDeleteEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDeferredDeleteEvent>(__jni_env, other0);
    QDeferredDeleteEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QDeferredDisposeEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QDeferredDeleteEvent* __qt_return_value = QDeferredDeleteEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QDeferredDeleteEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QDeferredDeleteEvent()
void __qt_construct_QDeferredDeleteEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDeferredDeleteEvent()")
    Q_UNUSED(__java_arguments)
    QDeferredDeleteEvent *__qt_this = new(__qtjambi_ptr) QDeferredDisposeEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDeferredDeleteEvent::QDeferredDeleteEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_initialize_1native__Lio_qt_core_QDeferredDisposeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDeferredDeleteEvent::QDeferredDeleteEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDeferredDeleteEvent, sizeof(QDeferredDisposeEvent_shell), typeid(QDeferredDeleteEvent), true, &deleter_QDeferredDeleteEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDeferredDeleteEvent(QDeferredDeleteEvent)
void __qt_construct_QDeferredDeleteEvent_cref_QDeferredDeleteEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDeferredDeleteEvent(QDeferredDeleteEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QDeferredDeleteEvent& __qt_arg__1 = qtjambi_cast<const QDeferredDeleteEvent& >(__jni_env, arg__1);
    QDeferredDeleteEvent *__qt_this = new(__qtjambi_ptr) QDeferredDisposeEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDeferredDeleteEvent::QDeferredDeleteEvent(QDeferredDeleteEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_initialize_1native__Lio_qt_core_QDeferredDisposeEvent_2Lio_qt_core_QDeferredDisposeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDeferredDeleteEvent::QDeferredDeleteEvent(QDeferredDeleteEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDeferredDeleteEvent_cref_QDeferredDeleteEvent, sizeof(QDeferredDisposeEvent_shell), typeid(QDeferredDeleteEvent), true, &deleter_QDeferredDeleteEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDeferredDisposeEvent_shell
void __qt_destruct_QDeferredDeleteEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDeferredDeleteEvent")
    reinterpret_cast<QDeferredDisposeEvent_shell*>(ptr)->~QDeferredDisposeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDeferredDeleteEvent::loopLevel()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_loopLevel_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QDeferredDeleteEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDeferredDeleteEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDeferredDeleteEvent::loopLevel()const", __qt_this)
        __java_return_value = __qt_this->loopLevel();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDeferredDeleteEvent::operator=(QDeferredDeleteEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_assign_1native_1cref_1QDeferredDeleteEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDeferredDeleteEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDeferredDeleteEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDeferredDeleteEvent::operator=(QDeferredDeleteEvent)", __qt_this)
        static_cast<QDeferredDisposeEvent_access*>(__qt_this)->__qt_assign_cref_QDeferredDeleteEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDeferredDeleteEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QDeferredDisposeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDeferredDeleteEvent *__qt_this = QtJambiAPI::objectFromNativeId<QDeferredDeleteEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDeferredDeleteEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QDeferredDisposeEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QDeferredDeleteEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QDeferredDeleteEvent>("QDeferredDeleteEvent", "io/qt/core/QDeferredDisposeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QDeferredDisposeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QDeferredDeleteEvent, {
        ConstructorInfo(&__qt_construct_QDeferredDeleteEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QDeferredDeleteEvent_cref_QDeferredDeleteEvent, "Lio/qt/core/QDeferredDisposeEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDeferredDeleteEvent);
    registerSizeOfShell(typeId, sizeof(QDeferredDisposeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QDeferredDeleteEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
